==> fuelcell-0.1.tar.gz: fuelcell-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'fuelcell',         # How you named your package folder (MyLib)
  packages = ['fuelcell'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'fuel cell data processing',   # Give a short description about your library
  author = 'Samay Garg',                   # Type in your name
  author_email = 'samay.garg@berkeley.edu',      # Type in your E-Mail
  url = 'https://github.com/user/fuelcell',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/user/reponame/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'pandas',
          'matplotlib'
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> fuelcell-0.2.tar.gz: fuelcell-0.2/setup.py <==
from distutils.core import setup
setup(
  name = 'fuelcell',         # How you named your package folder (MyLib)
  packages = ['fuelcell'],   # Chose the same as "name"
  version = '0.2',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'fuel cell data processing',   # Give a short description about your library
  author = 'Samay Garg',                   # Type in your name
  author_email = 'samay.garg@berkeley.edu',      # Type in your E-Mail
  url = 'https://github.com/samaygarg/fuelcell',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/samaygarg/fuelcell/archive/v_02.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'numpy',
          'pandas',
          'matplotlib'
      ],
  classifiers=[
    'Development Status :: 4 - Beta',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
